pub struct Cli {Show 14 fields
pub images: Vec<PathBuf>,
pub model: Option<String>,
pub oss: bool,
pub sandbox_mode: Option<SandboxModeCliArg>,
pub config_profile: Option<String>,
pub full_auto: bool,
pub dangerously_bypass_approvals_and_sandbox: bool,
pub cwd: Option<PathBuf>,
pub skip_git_repo_check: bool,
pub config_overrides: CliConfigOverrides,
pub color: Color,
pub json: bool,
pub last_message_file: Option<PathBuf>,
pub prompt: Option<String>,
}Fields
images: Vec<PathBuf>Optional image(s) to attach to the initial prompt.
model: Option<String>Model the agent should use.
oss: boolsandbox_mode: Option<SandboxModeCliArg>Select the sandbox policy to use when executing model-generated shell commands.
config_profile: Option<String>Configuration profile from config.toml to specify default options.
full_auto: boolConvenience alias for low-friction sandboxed automatic execution (-a on-failure, –sandbox workspace-write).
dangerously_bypass_approvals_and_sandbox: boolSkip all confirmation prompts and execute commands without sandboxing. EXTREMELY DANGEROUS. Intended solely for running in environments that are externally sandboxed.
cwd: Option<PathBuf>Tell the agent to use the specified directory as its working root.
skip_git_repo_check: boolAllow running Codex outside a Git repository.
config_overrides: CliConfigOverridescolor: ColorSpecifies color settings for use in the output.
json: boolPrint events to stdout as JSONL.
last_message_file: Option<PathBuf>Specifies file where the last message from the agent should be written.
prompt: Option<String>Initial instructions for the agent. If not provided as an argument (or
if - is used), instructions are read from stdin.